Updates
=======

.. cornice-autodoc::
   :modules: bodhi.server.services.updates, bodhi.server.services.zz_redirects
   :services: bodhi1_update_redirect, update, update_edit, update_get_test_results, update_request, update_waive_test_results, updates, updates_rss
